<?php

/**
 * The public-facing functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the public-facing stylesheet and JavaScript.
 *
 * @package    Trackboxx
 * @subpackage Trackboxx/public
 */
class Trackboxx_Public {
    /**
     * The ID of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $plugin_name The ID of this plugin.
     */
    private $plugin_name;

    /**
     * The version of this plugin.
     *
     * @since    1.0.0
     * @access   private
     * @var      string $version The current version of this plugin.
     */
    private $version;

    /**
     * Initialize the class and set its properties.
     *
     * @param string $plugin_name The name of the plugin.
     * @param string $version The version of this plugin.
     * @since    1.0.0
     */
    public function __construct( $plugin_name, $version ) {
        $this->plugin_name = $plugin_name;
        $this->version     = $version;
    }

    public function enqueue_styles() {
        wp_enqueue_style( $this->plugin_name,
            plugin_dir_url( __FILE__ ) . 'css/trackboxx-public.css', [],
            $this->version,
            'all'
        );
    }

    /**
     * Register the JavaScript for the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function enqueue_scripts() {
        $trackboxxId     = get_option( "trackboxx_tracking_id" );
        $canShowTbScript = ! is_admin() && ! is_embed() && isset( $trackboxxId["input"] ) && $trackboxxId["input"];
        ?>
        <?php if ( $canShowTbScript ) : ?>
            <script>
                (
                    function (d, s, id, w, f) {
                        w[f] = w[f] || function () {
                            (
                                w[f].q = w[f].q || []
                            ).push(arguments);
                        };
                        var js, fjs = d.getElementsByTagName(s)[0];
                        if (d.getElementById(id)) {
                            return;
                        }
                        js = d.createElement(s);
                        js.id = id;
                        js.onload = function () {
                            document.dispatchEvent(new Event('tbScriptLoaded'));
                        };
                        js.async = true;
                        js.src = "https://cdn.trackboxx.info/p/tracker.js";
                        fjs.parentNode.insertBefore(js, fjs);
                    }(document, "script", "trackboxx-script", window, "trackboxx")
                );
                trackboxx("set", "siteId", "<?php echo $trackboxxId["input"] ?>");
                trackboxx("trackPageview");
            </script>
        <?php endif; ?>
        <?php
    }

    public function wc_add_to_cart( $cart_id, $product_id ) {
        $_product = wc_get_product( $product_id );

        $trackboxxId = get_option( "trackboxx_tracking_id" );

        $url  = 'https://hit.trackboxx.info/hit-action';
        $data = [
            "p" => $_SERVER['REQUEST_URI'],
            "h" => ( ( $_SERVER['HTTPS'] === 'on' ) ? 'https://' : 'http://' ) . $_SERVER['HTTP_HOST'],
            "r" => $_SERVER['HTTP_REFERER'] ?? '',
            "res" => "",
            "tz" => "",
            "sid" => $trackboxxId['input'],
            "action" => "Purchase",
            "c" => [
                [
                    'type' => 'AddToCart',
                ],
                [
                    'type' => 'product',
                    'name' => $_product->get_name(),
                    'price' => $_product->get_price()
                ]
            ]
        ];

        $anonymizedIp = '0.0.0.0';
        if ( function_exists( 'wp_privacy_anonymize_ip' ) ) {
            $anonymizedIp = wp_privacy_anonymize_ip( $_SERVER['REMOTE_ADDR'] );
        }

        $args = [
            'body' => json_encode( $data ),
            'headers' => [
                'content-type' => 'text/plain',
                'user-agent' => $_SERVER['HTTP_USER_AGENT'],
                'X_FORWARDED_FOR' => $anonymizedIp
            ]
        ];

        wp_remote_post( $url, $args );
    }

    public function wc_purchase_tracking_script( $order_id ) {
        if ( ! $order_id ) {
            return;
        }

        $order = wc_get_order( $order_id );

        $params = [
            [
                'type' => 'order',
                'id' => $order_id,
                'total' => $order->get_total()
            ],
        ];

        if ( count( $order->get_items() ) > 0 ) {
            foreach ($order->get_coupons() as $coupon) {
                array_push( $params, [
                    'type' => 'coupon',
                    'name' => $coupon->get_code(),
                    'discount' => $coupon->get_discount()
                ] );
            }

            foreach ($order->get_items() as $item) {
                if ( 'line_item' == $item['type'] ) {
                    /**
                     * @var $_product WC_Product
                     */
                    $_product = $item->get_product();
                    $quantity = $item->get_quantity();

                    $price = $_product->get_price() * $quantity;

                    array_push( $params, [
                        'type' => 'product',
                        'name' => $_product->get_name(),
                        'price' => $price
                    ] );
                }
            }
        }

        ?>

        <script>
            trackboxx('Purchase', <?php echo json_encode( $params ); ?>);
        </script>

        <?php
    }
}
